Struct Security
pub struct Security {
pub action: SecurityAction,
pub permission_set: Arc<PermissionSet>,
}Expand description
Wrapper of the security information to store within the dotscope data types
Fields
action: SecurityActionThe action that describes how to apply the permission set to the code elements
permission_set: Arc<PermissionSet>The permission to be applied to the code elements