Struct AssemblyRaw

pub struct AssemblyRaw {
    pub rid: u32,
    pub token: Token,
    pub offset: usize,
    pub hash_alg_id: u32,
    pub major_version: u32,
    pub minor_version: u32,
    pub build_number: u32,
    pub revision_number: u32,
    pub flags: u32,
    pub public_key: u32,
    pub name: u32,
    pub culture: u32,
}
Represents a .NET CIL binary (assembly), TableId = 0x20

Fields

rid: u32

RowID

token: Token

Token

offset: usize

Offset

hash_alg_id: u32

a 4-byte constant of type AssemblyHashAlgorithm, II.23.1.1

major_version: u32

a 2-byte value specifying the Major version number

minor_version: u32

a 2-byte value specifying the Minor version number

build_number: u32

a 2-byte value specifying the Build number

revision_number: u32

a 2-byte value specifying the Revision number

flags: u32

a 4-byte bitmask of type AssemblyFlags, II.23.1.2

public_key: u32

an index into the Blob heap

name: u32

an index into the String heap

culture: u32

an index into the String heap

Implementations



impl AssemblyRaw

pub fn to_owned( &self, strings: &Strings<'_>, blobs: &Blob<'_>, ) -> Result<AssemblyRc>

Convert an AssemblyRaw, into a Assembly which has indexes resolved and owns the referenced data

Arguments
  • ‘strings’ - The #String heap
  • ‘blob’ - The #Blob heap
Errors

Returns an error if the string or blob data cannot be retrieved from the heaps

pub fn apply(&self) -> Result<()>

Apply an AssemblyRaw entry to update related metadata structures.

Assembly entries are self-contained and represent the current assembly metadata. They don’t require cross-table updates during the dual variant resolution phase.

Errors

Always returns Ok(()) as Assembly entries don’t modify other tables.