Struct FileRaw

pub struct FileRaw {
    pub rid: u32,
    pub token: Token,
    pub offset: usize,
    pub flags: u32,
    pub name: u32,
    pub hash_value: u32,
}
The File table lists the files that make up the current assembly. TableId = 0x26

Fields

rid: u32

RowID

token: Token

Token

offset: usize

Offset

flags: u32

a 4-byte bitmask of type FileAttributes, II.23.1.6

name: u32

an index into the String heap

hash_value: u32

an index into the Blob heap

Implementations



impl FileRaw

pub fn to_owned(&self, blob: &Blob<'_>, strings: &Strings<'_>) -> Result<FileRc>

Convert an FileRaw, into a File which has indexes resolved and owns the referenced data

Arguments
  • ‘blob’ - The #Blob heap
  • ‘strings’ - All parsed Param entries
Errors

Returns an error if string or blob lookup fails

pub fn apply(&self) -> Result<()>

Apply a FileRaw entry to update related metadata structures.

File entries define files that are part of this assembly. They are primarily metadata descriptors and don’t require cross-table updates during the dual variant resolution phase.

Errors

Always returns Ok(()) as File entries don’t modify other tables.