Struct GenericParamConstraintRaw
pub struct GenericParamConstraintRaw {
pub rid: u32,
pub token: Token,
pub offset: usize,
pub owner: u32,
pub constraint: CodedIndex,
}Expand description
The GenericParamConstraint table defines constraints on generic parameters. TableId = 0x2C
Fields
rid: u32RowID
token: TokenToken
offset: usizeOffset
owner: u32an index into the GenericParam table
constraint: CodedIndexan index into the TypeDefOrRef coded index
Implementations
impl GenericParamConstraintRaw
impl GenericParamConstraintRaw
pub fn apply(
&self,
generic_params: &GenericParamMap,
types: &TypeRegistry,
) -> Result<()>
pub fn apply( &self, generic_params: &GenericParamMap, types: &TypeRegistry, ) -> Result<()>
pub fn to_owned(
&self,
generic_params: &GenericParamMap,
types: &TypeRegistry,
) -> Result<GenericParamConstraintRc>
pub fn to_owned( &self, generic_params: &GenericParamMap, types: &TypeRegistry, ) -> Result<GenericParamConstraintRc>
Convert an GenericParamConstraintRaw, into a GenericParamConstraint which has indexes resolved and owns the referenced data
Arguments
- ‘
generic_params’ - All parsedGenericParamentries - ‘types’ - All parsed
TypeDef,TypeRefandTypeSpecentries
Errors
Returns an error if generic parameter or constraint type lookup fails