Struct Param

pub struct Param {
    pub rid: u32,
    pub token: Token,
    pub offset: usize,
    pub flags: u32,
    pub sequence: u32,
    pub name: Option<String>,
    pub default: OnceLock<CilPrimitive>,
    pub marshal: OnceLock<MarshallingInfo>,
    pub modifiers: CilTypeRefList,
    pub base: OnceLock<CilTypeRef>,
    pub is_by_ref: AtomicBool,
    pub custom_attributes: CustomAttributeValueList,
}
The Param table defines parameters for methods in the MethodDef table. Similar to ParamRaw but with resolved indexes and owned data.

Fields

rid: u32

RowID

token: Token

Token

offset: usize

Offset

flags: u32

bitmask of ParamAttributes, II.23.1.13

sequence: u32

The sequence number (0 for return value)

name: Option<String>

The parameter name

default: OnceLock<CilPrimitive>

flags.HAS_DEFAULT -> This is the default value of this parameter

marshal: OnceLock<MarshallingInfo>

flags.HAS_MARSHAL -> The marshal instructions for PInvoke

modifiers: CilTypeRefList

Custom modifiers that are applied to this Param

base: OnceLock<CilTypeRef>

The underlaying type of this Param

is_by_ref: AtomicBool

Is the parameter passed by reference

custom_attributes: CustomAttributeValueList

Custom attributes applied to this parameter

Implementations



impl Param

pub fn apply_signature( &self, signature: &SignatureParameter, types: Arc<TypeRegistry>, ) -> Result<()>

Apply a signature to this parameter, will cause update with type information

Errors

Returns an error if type resolution fails, if modifier types cannot be resolved, or if the base type has already been set for this parameter.

Arguments
  • ‘signature’ - The signature to apply to this parameter
  • ‘types’ - The type registry for lookup and generation of types