Type Alias StandAloneSigMap
pub type StandAloneSigMap = SkipMap<Token, StandAloneSigRc>;Expand description
A map that holds the mapping of Token to parsed StandAloneSig
Aliased Type
pub struct StandAloneSigMap { /* private fields */ }pub type StandAloneSigMap = SkipMap<Token, StandAloneSigRc>;A map that holds the mapping of Token to parsed StandAloneSig
pub struct StandAloneSigMap { /* private fields */ }