Struct LocalScopeRef
pub struct LocalScopeRef { /* private fields */ }Expand description
Weak reference to a LocalScope to avoid circular dependencies
Since scopes can form tree structures where parent scopes might reference child scopes or vice versa, we use weak references to prevent memory leaks from circular references.
Implementations
impl LocalScopeRef
impl LocalScopeRef
pub fn new(strong_ref: &LocalScopeRc) -> Self
pub fn new(strong_ref: &LocalScopeRc) -> Self
Create a new LocalScopeRef from a strong reference
pub fn upgrade(&self) -> Option<LocalScopeRc>
pub fn upgrade(&self) -> Option<LocalScopeRc>
Upgrade the weak reference to a strong reference if still valid