Trait TableRow
pub trait TableRow: Send {
// Required method
fn row_size(sizes: &TableInfoRef) -> u32;
}Expand description
Trait for types that represent a row in a metadata table and can report their row size.
This trait provides the canonical method for determining the size in bytes of a single row for a given table type, taking into account variable-sized fields.
Required Methods
fn row_size(sizes: &TableInfoRef) -> u32
fn row_size(sizes: &TableInfoRef) -> u32
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.