Type Alias LocalConstantMap

pub type LocalConstantMap = SkipMap<Token, LocalConstantRc>;
A map that holds the mapping of crate::metadata::token::Token to parsed LocalConstant

Thread-safe concurrent map using skip list data structure for efficient lookups and insertions. Used to cache resolved local constant information by their metadata tokens.

Aliased Type

pub struct LocalConstantMap { /* private fields */ }