MethodSpecList

Type Alias MethodSpecList 

pub type MethodSpecList = Arc<Vec<MethodSpecRc>>;
Thread-safe vector holding a list of MethodSpec entries.

Uses a lock-free vector implementation for efficient concurrent access to the collection of all method specification entries in the metadata.

Aliased Type

pub struct MethodSpecList { /* private fields */ }