Struct CilPrimitive

pub struct CilPrimitive {
    pub kind: CilPrimitiveKind,
    pub data: CilPrimitiveData,
}
Represents all primitive types in CIL/.NET with optional data

Fields

kind: CilPrimitiveKind

The type of primitive

data: CilPrimitiveData

The actual data (if available)

Implementations



impl CilPrimitive

pub fn new(kind: CilPrimitiveKind) -> Self

Create a new primitive with the default value

Arguments
  • kind - The type or primitive to create

pub fn with_data(kind: CilPrimitiveKind, data: CilPrimitiveData) -> Self

Create a primitive with specific data

Arguments
  • kind - Set the kind of primitive
  • data - Set the data for the primitive

pub fn boolean(value: bool) -> Self

Create a boolean primitive

Arguments
  • value - The initial value for the requested primitive

pub fn char(value: char) -> Self

Create a character primitive

Arguments
  • value - The initial value for the requested primitive

pub fn i1(value: i8) -> Self

Create an i8 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn u1(value: u8) -> Self

Create a u8 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn i2(value: i16) -> Self

Create an i16 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn u2(value: u16) -> Self

Create a u16 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn i4(value: i32) -> Self

Create an i32 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn u4(value: u32) -> Self

Create a u32 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn i8(value: i64) -> Self

Create an i64 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn u8(value: u64) -> Self

Create a u64 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn r4(value: f32) -> Self

Create an f32 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn r8(value: f64) -> Self

Create an f64 primitive

Arguments
  • value - The initial value for the requested primitive

pub fn u(value: usize) -> Self

Create an usize primitive

Arguments
  • value - The initial value for the requested primitive

pub fn i(value: isize) -> Self

Create an isize primitive

Arguments
  • value - The initial value for the requested primitive

pub fn string(value: &str) -> Self

Create a string primitive

Arguments
  • value - The initial value for the requested primitive

pub fn null() -> Self

Create a null primitive

pub fn token(&self) -> Token

Get the token for this primitive type

pub fn as_byte(&self) -> u8

Get the byte representation in type signatures (per ECMA-335 spec)

pub fn from_byte(byte: u8) -> Result<Self>

Try to parse a primitive type from a signature byte

Arguments
  • byte - The kind byte to convert
Errors

Returns TypeNotPrimitive if the byte does not represent a valid primitive type.

pub fn clr_full_name(&self) -> &'static str

Get the CLR full type name (with namespace)

pub fn namespace(&self) -> &'static str

Get the namespace of this type

pub fn name(&self) -> &'static str

Get the short name (without namespace)

pub fn to_flavor(&self) -> CilFlavor

Convert to CilFlavor

pub fn is_value_type(&self) -> bool

Is this a value type

pub fn is_reference_type(&self) -> bool

Is this a reference type

pub fn from_blob(p_type: u8, blob: &[u8]) -> Result<Self>

Parse a primitive value from a blob of data

Arguments
  • p_type - The primitive byte to determine the kind of
  • blob - The data blob to parse for the value
Errors

Returns TypeNotPrimitive if the primitive type is invalid. Returns OutOfBounds or other errors if the blob data is insufficient or invalid.

pub fn as_boolean(&self) -> Option<bool>

Try to get as boolean value

pub fn as_i32(&self) -> Option<i32>

Try to get as i32 value

pub fn as_i64(&self) -> Option<i64>

Try to get as i64 value

pub fn as_f64(&self) -> Option<f64>

Try to get as f64 value

pub fn as_string(&self) -> Option<String>

Try to get as string value

pub fn to_bytes(&self) -> Vec<u8>

Serialize this primitive to bytes