Struct CilTypeRef

pub struct CilTypeRef { /* private fields */ }
A smart reference to a CilType that automatically handles weak references to prevent circular reference memory leaks while providing a clean API

Implementations



impl CilTypeRef

pub fn new(strong_ref: &CilTypeRc) -> Self

Create a new CilTypeRef from a strong reference

pub fn upgrade(&self) -> Option<CilTypeRc>

Get a strong reference to the type, returning None if the type has been dropped

pub fn expect(&self, msg: &str) -> CilTypeRc

Get a strong reference to the type, panicking if the type has been dropped Use this when you’re certain the type should still exist

Panics

Panics if the type has been dropped and the weak reference cannot be upgraded.

pub fn is_valid(&self) -> bool

Check if the referenced type is still alive

pub fn token(&self) -> Option<Token>

Get the token of the referenced type (if still alive)

pub fn name(&self) -> Option<String>

Get the name of the referenced type (if still alive)

pub fn namespace(&self) -> Option<String>

Get the namespace of the referenced type (if still alive)

pub fn nested_types(&self) -> Option<CilTypeRefList>

Get the nested_types collection of the referenced type (if still alive)

pub fn generic_params(&self) -> Option<GenericParamList>

Get the generic_params collection of the referenced type (if still alive)

pub fn generic_args(&self) -> Option<MethodSpecList>

Get the generic_args collection of the referenced type (if still alive)