Struct Guid
pub struct Guid<'a> { /* private fields */ }Expand description
‘#GUID’ is a heap, which contains a sequence of 128-bit GUIDs
The Guid object provides helper methods to access the data within this blob, and parse / process it
properly according to the standard.
Examples
use dotscope::metadata::streams::Guid;
let data = &[0u8; 32];
let guid_heap = Guid::from(data).unwrap();
// Accessing GUIDs would require valid data and indexReference
Implementations
impl<'a> Guid<'a>
impl<'a> Guid<'a>
pub fn iter(&self) -> GuidIterator<'_> ⓘ
pub fn iter(&self) -> GuidIterator<'_> ⓘ
Returns an iterator over all GUIDs in the heap
Provides access to all 16-byte GUID entries in sequential order.
Each iteration yields a Result<(usize, uguid::Guid)> with the index and GUID value.
Examples
use dotscope::metadata::streams::Guid;
let data = &[0u8; 32]; // Two empty GUIDs
let guids = Guid::from(data).unwrap();
for result in guids.iter() {
match result {
Ok((index, guid)) => println!("GUID {}: {}", index, guid),
Err(e) => eprintln!("Error: {}", e),
}
}Trait Implementations