Struct MethodDefRaw
pub struct MethodDefRaw {
pub rid: u32,
pub token: Token,
pub offset: usize,
pub rva: u32,
pub impl_flags: u32,
pub flags: u32,
pub name: u32,
pub signature: u32,
pub param_list: u32,
}Expand description
The MethodDef table defines methods for types in the TypeDef table. TableId = 0x06
Fields
rid: u32RowID
token: TokenToken
offset: usizeOffset
rva: u32a 4-byte constant
impl_flags: u32bitmask of MethodImplAttributes, II.23.1.10
flags: u32bitmask of MethodAttributes, II.23.1.10
name: u32an index into the String heap
signature: u32an index into the Blob heap
param_list: u32an index into the Param table
Implementations
impl MethodDefRaw
impl MethodDefRaw
pub fn to_owned(
&self,
strings: &Strings<'_>,
blob: &Blob<'_>,
params_map: &ParamMap,
table: &MetadataTable<'_, MethodDefRaw>,
) -> Result<MethodRc>
pub fn to_owned( &self, strings: &Strings<'_>, blob: &Blob<'_>, params_map: &ParamMap, table: &MetadataTable<'_, MethodDefRaw>, ) -> Result<MethodRc>
Convert an MethodDefRaw, into a Method which has indexes resolved and owns the referenced data
Arguments
- ‘strings’ - The processed Strings
- ‘blob’ - The processed Blobs
- ‘
params_map’ - All parsedParamentries for param resolution - ‘table’ - The
MethodDeftable for getting next row’sparam_list
Errors
Returns an error if the method name cannot be retrieved from the strings heap, or if the method signature cannot be parsed from the blob heap.
pub fn apply(&self) -> Result<()>
pub fn apply(&self) -> Result<()>
Apply a MethodDefRaw entry to update related metadata structures.
MethodDef entries define methods within types. They are associated with their parent
types but don’t themselves modify other metadata during the dual variant resolution phase.
Method-specific metadata (P/Invoke info, generic parameters, etc.) is resolved separately.
Errors
Always returns Ok(()) as MethodDef entries don’t modify other tables directly.