Struct Module
pub struct Module {
pub rid: u32,
pub token: Token,
pub offset: usize,
pub generation: u32,
pub name: String,
pub mvid: Guid,
pub encid: Option<Guid>,
pub encbaseid: Option<Guid>,
pub imports: Vec<ImportRc>,
pub custom_attributes: CustomAttributeValueList,
}Expand description
The Module table provides information about the current module, including its name, GUID (Mvid), and generation. There
is only one row in this table for each PE file. Similar to ModuleRaw but with resolved indexes and owned data.
Fields
rid: u32RowID
token: TokenToken
offset: usizeOffset
generation: u32a 2-byte value, reserved, shall be zero
name: StringName of this module
mvid: GuidA Guid used to distinguish between two versions of the same module
encid: Option<Guid>an index into the Guid heap; reserved, shall be zero
encbaseid: Option<Guid>an index into the Guid heap; reserved, shall be zero
imports: Vec<ImportRc>All CilType and MethodDef entries that are imported from this module
custom_attributes: CustomAttributeValueListCustom attributes attached to this module