Struct StreamHeader
pub struct StreamHeader {
pub offset: u32,
pub size: u32,
pub name: String,
}Expand description
A stream header provides the names, and the position and length of a particular table or heap. Note that the length of a Stream header structure is not fixed, but depends on the length of its name field (a variable length null-terminated string).
Reference
Examples
use dotscope::metadata::streams::StreamHeader;
let data = [0u8; 16];
let result = StreamHeader::from(&data[..]);
assert!(result.is_err() || result.is_ok());Fields
offset: u32Memory offset with start of the stream
size: u32Size of this stream in bytes, shall be a multiple of 4
name: StringName of Stream\0 max 32char
Implementations
impl StreamHeader
impl StreamHeader