Module ParamAttributes
Parameter attribute flags for the Param table.
This module defines all possible flags that can be set in the Flags field
of Param entries according to ECMA-335 II.23.1.13. These flags control
parameter behavior, direction, and characteristics.
Constants
- HAS_
DEFAULT - Parameter has a default value defined.
- HAS_
FIELD_ MARSHAL - Parameter has marshalling information defined.
- IN
- Parameter is an input parameter (passed to the method).
- OPTIONAL
- Parameter is optional and may be omitted in calls.
- OUT
- Parameter is an output parameter (data flows out of the method).
- UNUSED
- Reserved bits that shall be zero in conforming implementations.