Type Alias ImportScopeMap
pub type ImportScopeMap = SkipMap<Token, ImportScopeRc>;Expand description
A map that holds the mapping of crate::metadata::token::Token to parsed ImportScope
Thread-safe concurrent map using skip list data structure for efficient lookups and insertions. Used to cache resolved import scope information by their metadata tokens.
Aliased Type
pub struct ImportScopeMap { /* private fields */ }