Struct CilPrimitive
pub struct CilPrimitive {
pub kind: CilPrimitiveKind,
pub data: CilPrimitiveData,
}Expand description
Represents all primitive types in CIL/.NET with optional data
Fields
kind: CilPrimitiveKindThe type of primitive
data: CilPrimitiveDataThe actual data (if available)
Implementations
impl CilPrimitive
impl CilPrimitive
pub fn new(kind: CilPrimitiveKind) -> Self
pub fn new(kind: CilPrimitiveKind) -> Self
pub fn with_data(kind: CilPrimitiveKind, data: CilPrimitiveData) -> Self
pub fn with_data(kind: CilPrimitiveKind, data: CilPrimitiveData) -> Self
Create a primitive with specific data
Arguments
kind- Set the kind of primitivedata- Set the data for the primitive
pub fn null() -> Self
pub fn null() -> Self
Create a null primitive
pub fn from_byte(byte: u8) -> Result<Self>
pub fn from_byte(byte: u8) -> Result<Self>
Try to parse a primitive type from a signature byte
Arguments
byte- The kind byte to convert
Errors
Returns TypeNotPrimitive if the byte does not represent a valid primitive type.
pub fn clr_full_name(&self) -> &'static str
pub fn clr_full_name(&self) -> &'static str
Get the CLR full type name (with namespace)
pub fn is_value_type(&self) -> bool
pub fn is_value_type(&self) -> bool
Is this a value type
pub fn is_reference_type(&self) -> bool
pub fn is_reference_type(&self) -> bool
Is this a reference type
pub fn from_blob(p_type: u8, blob: &[u8]) -> Result<Self>
pub fn from_blob(p_type: u8, blob: &[u8]) -> Result<Self>
Parse a primitive value from a blob of data
Arguments
p_type- The primitive byte to determine the kind ofblob- The data blob to parse for the value
Errors
Returns TypeNotPrimitive if the primitive type is invalid.
Returns OutOfBounds or other errors if the blob data is insufficient or invalid.
pub fn as_boolean(&self) -> Option<bool>
pub fn as_boolean(&self) -> Option<bool>
Try to get as boolean value