Struct CilType

pub struct CilType {
Show 20 fields pub token: Token, pub namespace: String, pub name: String, pub external: Option<CilTypeReference>, pub flags: u32, pub fields: FieldList, pub methods: MethodRefList, pub properties: PropertyList, pub events: EventList, pub interfaces: CilTypeRefList, pub overwrites: Arc<Vec<CilTypeReference>>, pub nested_types: CilTypeRefList, pub generic_params: GenericParamList, pub generic_args: MethodSpecList, pub custom_attributes: CustomAttributeValueList, pub packing_size: OnceLock<u16>, pub class_size: OnceLock<u32>, pub spec: OnceLock<CilFlavor>, pub modifiers: Arc<Vec<CilModifier>>, pub security: OnceLock<Security>, /* private fields */
}
Represents a ‘Type’, close to TypeDef and TypeRef but as a combined item, containing more information. The Token will match either the TypeDef or TypeRef or TypeSpec or TypeBase (artificial, for mapping to specific primitive types supported in the runtime).

Fields

token: Token

Token

namespace: String

TypeNamespace (can be empty, e.g. for artificial <module> (globals) )

name: String

TypeName

external: Option<CilTypeReference>

Type is imported (e.g. AssemblyRef, File, ModuleRef, …)

flags: u32

Flags (a 4-byte bitmask of type TypeAttributes, II.23.1.15)

fields: FieldList

All fields this type has

methods: MethodRefList

All methods this type has

properties: PropertyList

All properties this type has

events: EventList

All events this type has

interfaces: CilTypeRefList

All interfaces this class implements

overwrites: Arc<Vec<CilTypeReference>>

All method overwrites this type implements (e.g. Interfaces)

nested_types: CilTypeRefList

All types that are ‘contained’ in this type

generic_params: GenericParamList

All generic parameters this type has (type information, not the instantiated version)

generic_args: MethodSpecList

All generic arguments this type has (instantiated version)

custom_attributes: CustomAttributeValueList

All custom attributes this type has

packing_size: OnceLock<u16>

a 2-byte value, specifying the alignment of fields

class_size: OnceLock<u32>

a 4-byte value, specifying the size of the class

spec: OnceLock<CilFlavor>

TypeSpec specifiers for the type

modifiers: Arc<Vec<CilModifier>>

Type modifiers from TypeSpec for this type

security: OnceLock<Security>

The .NET CIL Security Information (if present)

Implementations



impl CilType

pub fn new( token: Token, namespace: String, name: String, external: Option<CilTypeReference>, base: Option<CilTypeRef>, flags: u32, fields: FieldList, methods: MethodRefList, flavor: Option<CilFlavor>, ) -> Self

Create a new instance of a CilType

Arguments
  • token - The token for this type
  • namespace - The namespace of the type
  • name - The name of the type
  • external - External type reference if this is an imported type
  • base - Base type reference if this type inherits from another
  • flags - Type attributes flags
  • fields - Fields belonging to this type
  • methods - Methods belonging to this type
  • flavor - Optional explicit flavor. If None, flavor will be computed lazily

pub fn set_base(&self, base_type: CilTypeRef) -> Result<(), CilTypeRef>

Set the base type of this type (for interface inheritance)

Errors

Returns Err(base_type) if a base type was already set for this type. The error contains the base_type that was attempted to be set.

Returns

Ok(()) if the base type was set successfully.

pub fn base(&self) -> Option<CilTypeRc>

Access the base type of this type, if it exists

pub fn flavor(&self) -> &CilFlavor

Get the computed type flavor - determined lazily from context

pub fn fullname(&self) -> String

Returns the full name (Namespace.Name) of the entity