Struct CilTypeRef
pub struct CilTypeRef { /* private fields */ }Expand description
A smart reference to a CilType that automatically handles weak references
to prevent circular reference memory leaks while providing a clean API
Implementations
impl CilTypeRef
impl CilTypeRef
pub fn upgrade(&self) -> Option<CilTypeRc>
pub fn upgrade(&self) -> Option<CilTypeRc>
Get a strong reference to the type, returning None if the type has been dropped
pub fn expect(&self, msg: &str) -> CilTypeRc
pub fn expect(&self, msg: &str) -> CilTypeRc
Get a strong reference to the type, panicking if the type has been dropped Use this when you’re certain the type should still exist
Panics
Panics if the type has been dropped and the weak reference cannot be upgraded.
pub fn nested_types(&self) -> Option<CilTypeRefList>
pub fn nested_types(&self) -> Option<CilTypeRefList>
Get the nested_types collection of the referenced type (if still alive)
pub fn generic_params(&self) -> Option<GenericParamList>
pub fn generic_params(&self) -> Option<GenericParamList>
Get the generic_params collection of the referenced type (if still alive)
pub fn generic_args(&self) -> Option<MethodSpecList>
pub fn generic_args(&self) -> Option<MethodSpecList>
Get the generic_args collection of the referenced type (if still alive)